# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protocookie.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='protocookie.proto',
  package='protocookie',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x11protocookie.proto\x12\x0bprotocookie\"\x86\x01\n\x07Service\x12\x11\n\tserviceID\x18\x01 \x02(\x05\x12\x13\n\x0bserviceName\x18\x02 \x02(\t\x12(\n\x05roles\x18\x03 \x03(\x0e\x32\x19.protocookie.Service.Role\")\n\x04Role\x12\t\n\x05OWNER\x10\x00\x12\n\n\x06\x45\x44ITOR\x10\x01\x12\n\n\x06VIEWER\x10\x02\"L\n\x04User\x12\x10\n\x08username\x18\x01 \x02(\t\x12\n\n\x02id\x18\x02 \x02(\x05\x12&\n\x08services\x18\x03 \x03(\x0b\x32\x14.protocookie.Service')
)



_SERVICE_ROLE = _descriptor.EnumDescriptor(
  name='Role',
  full_name='protocookie.Service.Role',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OWNER', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EDITOR', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIEWER', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=128,
  serialized_end=169,
)
_sym_db.RegisterEnumDescriptor(_SERVICE_ROLE)


_SERVICE = _descriptor.Descriptor(
  name='Service',
  full_name='protocookie.Service',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='serviceID', full_name='protocookie.Service.serviceID', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='protocookie.Service.serviceName', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='roles', full_name='protocookie.Service.roles', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SERVICE_ROLE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35,
  serialized_end=169,
)


_USER = _descriptor.Descriptor(
  name='User',
  full_name='protocookie.User',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='protocookie.User.username', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='protocookie.User.id', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='services', full_name='protocookie.User.services', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=171,
  serialized_end=247,
)

_SERVICE.fields_by_name['roles'].enum_type = _SERVICE_ROLE
_SERVICE_ROLE.containing_type = _SERVICE
_USER.fields_by_name['services'].message_type = _SERVICE
DESCRIPTOR.message_types_by_name['Service'] = _SERVICE
DESCRIPTOR.message_types_by_name['User'] = _USER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Service = _reflection.GeneratedProtocolMessageType('Service', (_message.Message,), dict(
  DESCRIPTOR = _SERVICE,
  __module__ = 'protocookie_pb2'
  # @@protoc_insertion_point(class_scope:protocookie.Service)
  ))
_sym_db.RegisterMessage(Service)

User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), dict(
  DESCRIPTOR = _USER,
  __module__ = 'protocookie_pb2'
  # @@protoc_insertion_point(class_scope:protocookie.User)
  ))
_sym_db.RegisterMessage(User)


# @@protoc_insertion_point(module_scope)
